@@ -33,10 +33,12 @@ def mms_part_slice2d(trange=None,
                      resolution=None,
                      interpolation='geometric',
                      smooth=None,
+                     save_jpeg=None,
                      save_png=None,
                      save_svg=None,
                      save_pdf=None,
                      save_eps=None,
+                     plotsize=10,
                      dpi=None,
                      return_slice=False,
                      display=True):
@@ -259,4 +261,4 @@ def mms_part_slice2d(trange=None,
         return the_slice
 
     plot(the_slice, xrange=xrange, yrange=yrange, zrange=zrange, save_png=save_png, save_svg=save_svg,
-         save_pdf=save_pdf, save_eps=save_eps, display=display, dpi=dpi)
+         save_pdf=save_pdf, save_eps=save_eps, save_jpeg=save_jpeg, display=display, dpi=dpi, plotsize=plotsize)
