@@ -593,7 +593,7 @@ def _make_SECS_plots(data=None, dtime=None, contour_den=8, s_loc=False):
     if s_loc:
         m.scatter(lon, lat, latlon=True, marker='*', c='black')
     cb = m.colorbar(matplotlib.cm.ScalarMappable(norm=norm_cb, cmap='seismic'), pad='15%')
-    cb.set_label(r'$\mathit{J} \  (mA/m)$')
+    cb.set_label(r'$\mathit{J} \  (A)$')
     ax_cb = cb.ax
     text = ax_cb.yaxis.label
     font_cb = matplotlib.font_manager.FontProperties(family='times new roman', style='italic', size=20)
@@ -638,4 +638,4 @@ def make_plots(dtype='EICS', dtime=None, vplot_sized=True, contour_den=100, s_lo
     if dtype == 'SECS':
         _make_SECS_plots(dtime=dtime, contour_den=contour_den, s_loc=s_loc)
         # make a contour map.
-    return
\ No newline at end of file
+    return
